package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/NestHost.class */
public final class NestHost extends Attribute {
    private int hostClassIndex;

    /* JADX INFO: Access modifiers changed from: package-private */
    public NestHost(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, 0, constantPool);
        this.hostClassIndex = input.readUnsignedShort();
    }

    public NestHost(int nameIndex, int length, int hostClassIndex, ConstantPool constantPool) {
        super((byte) 26, nameIndex, length, constantPool);
        this.hostClassIndex = hostClassIndex;
    }

    public NestHost(NestHost c) {
        this(c.getNameIndex(), c.getLength(), c.getHostClassIndex(), c.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitNestHost(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        NestHost c = (NestHost) clone();
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.hostClassIndex);
    }

    public int getHostClassIndex() {
        return this.hostClassIndex;
    }

    public void setHostClassIndex(int hostClassIndex) {
        this.hostClassIndex = hostClassIndex;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        StringBuilder buf = new StringBuilder();
        buf.append("NestHost: ");
        String className = super.getConstantPool().getConstantString(this.hostClassIndex, (byte) 7);
        buf.append(Utility.compactClassName(className, false));
        return buf.toString();
    }
}
